@@ -9,7 +9,7 @@ import subprocess
 import traceback
 import hashlib
 import lzma
-
+from symbol import except_clause
 
 try:
     import bflb_path
@@ -49,7 +49,7 @@ if conf_sign:
     chip_xtal = cgc.choice_xtal
     chip_brd = cgc.choice_board
     bl_factory_params_file_prefix = cgc.show_text_first_value
-    boot2bin = "chipsp_boot2.bin"  
+      
 else:
     chip_dict = {
         "bl56x": "bl60x",
@@ -57,12 +57,14 @@ else:
         "bl562": "bl602",
         "bl602": "bl602",
         "bl702": "bl702",
-        "bl606p": "bl606p",
+        "bl808": "bl808",
     }
     chip_xtal = 'bl60x_xtal'
     chip_brd = 'bl60x_brd'
     bl_factory_params_file_prefix = 'bl_factory_params_'
-    boot2bin = "blsp_boot2.bin"
+   
+    
+boot2_dir = 'boot2_iap_v5.0'
 
 
 def parse_rfpa(bin):
@@ -161,7 +163,7 @@ class BflbIotTool(object):
         else:
             bh_cfg_file_org = os.path.join(chip_path, chipname,
                                            "efuse_bootheader/efuse_bootheader_cfg.conf")
-        self.bh_cfg_file = os.path.join(chip_path, chipname, "efuse_bootheader/efuse_bootheader_cfg.ini")
+        self.bh_cfg_file = os.path.join(chip_path, chipname, "img_create_iot/efuse_bootheader_cfg.ini")
         if os.path.isfile(self.bh_cfg_file) is False:
             shutil.copyfile(bh_cfg_file_org, self.bh_cfg_file)
         
@@ -408,9 +410,9 @@ class BflbIotTool(object):
             header.append(0xFF)
             header_len = header_len - 1
         return header
-    
-  
-    def bl60x_mfg_ota_xz_gen(self, chipname="bl60x", chiptype="bl60x", cpu_type=None):
+
+
+    def bl60x_mfg_ota_xz_gen(self, ota_path, chipname="bl60x", chiptype="bl60x", cpu_type=None):
         bl60x_xz_filters = [
             {
                 "id": lzma.FILTER_LZMA2,
@@ -421,17 +423,17 @@ class BflbIotTool(object):
         fw_ota_bin = bytearray()
         fw_ota_bin_xz = bytearray()
         if cpu_type is None:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin")
+            fw_ota_path = os.path.join(ota_path, "FW_OTA.bin")
         else:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin")
+            fw_ota_path = os.path.join(ota_path, cpu_type + "_OTA.bin")
         with open(fw_ota_path, mode="rb") as bin_f:
             file_bytes = bin_f.read()
             for b in file_bytes:
                 fw_ota_bin.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.xz")
+            fw_ota_path = os.path.join(ota_path, "FW_OTA.bin.xz")
         else:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz")
+            fw_ota_path = os.path.join(ota_path, cpu_type + "_OTA.bin.xz")
         with lzma.open(fw_ota_path, mode="wb", check=lzma.CHECK_CRC32,
                        filters=bl60x_xz_filters) as xz_f:
             xz_f.write(fw_ota_bin)
@@ -443,20 +445,26 @@ class BflbIotTool(object):
         for b in fw_ota_bin_xz:
             fw_ota_bin_xz_ota.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.xz.ota")
+            fw_ota_path = os.path.join(ota_path, "FW_OTA.bin.xz.ota")
+            fw_ota_path1 = os.path.join(ota_path, "FW_OTA.bin.hash")
         else:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz.ota")
+            fw_ota_path = os.path.join(ota_path, cpu_type + "_OTA.bin.xz.ota")
+            fw_ota_path1 = os.path.join(ota_path, cpu_type + "_OTA.bin.hash")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin_xz_ota)
         with open(fw_ota_path.replace(".ota", ".hash"), mode="wb") as f:
             f.write(fw_ota_bin_xz + img_create_sha256_data(fw_ota_bin_xz))
+        with open(fw_ota_path1, mode="wb") as f:
+            f.write(fw_ota_bin + img_create_sha256_data(fw_ota_bin_xz))
     
     
-    def bl60x_mfg_ota_bin_gen(self, chipname="bl60x", chiptype="bl60x", cpu_type=None):
+    def bl60x_mfg_ota_bin_gen(self, chipname="bl60x", chiptype="bl60x", cpu_type=None, version=None, dir_ota=None):
         fw_header_len = 4096
         fw_ota_bin = bytearray()
-    
-        ota_path = os.path.join(chip_path, chipname, "ota")
+        if dir_ota: 
+            ota_path = dir_ota 
+        else:
+            ota_path = os.path.join(chip_path, chipname, "ota")
         if os.path.isdir(ota_path) is False:
             os.mkdir(ota_path)
     
@@ -486,24 +494,24 @@ class BflbIotTool(object):
                 fw_ota_bin.append(b)
         fw_ota_bin_header = self.bl60x_mfg_ota_header(chipname, fw_ota_bin, use_xz=0)
         if cpu_type is None:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin")
+            fw_ota_path = os.path.join(ota_path, "FW_OTA.bin")
         else:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin")
+            fw_ota_path = os.path.join(ota_path, cpu_type + "_OTA.bin")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin)
+    
         for b in fw_ota_bin:
             fw_ota_bin_header.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.ota")
+            fw_ota_path = os.path.join(ota_path, "FW_OTA.bin.ota")
         else:
-            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.ota")
+            fw_ota_path = os.path.join(ota_path, cpu_type + "_OTA.bin.ota")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin_header)
         bflb_utils.printf("FW OTA bin is Done. Len is %d" % len(fw_ota_bin))
-        self.bl60x_mfg_ota_xz_gen(chipname, chiptype, cpu_type)
+        self.bl60x_mfg_ota_xz_gen(ota_path, chipname, chiptype, cpu_type)
         bflb_utils.printf("FW OTA xz is Done")
-    
-    
+       
     def bl60x_image_gen(self,
                         chipname,
                         chiptype,
@@ -520,8 +528,12 @@ class BflbIotTool(object):
         if key or (publickey and privarekey):
             img_cfg = BFConfigParser()
             img_cfg.read(f)
-            efusefile = img_cfg.get("Img_Cfg", "efuse_file")
-            efusemaskfile = img_cfg.get("Img_Cfg", "efuse_mask_file")
+            if chiptype == "bl60x":
+                efusefile = img_cfg.get("Img_CPU0_Cfg", "efuse_file")
+                efusemaskfile = img_cfg.get("Img_CPU0_Cfg", "efuse_mask_file")
+            else:
+                efusefile = img_cfg.get("Img_Cfg", "efuse_file")
+                efusemaskfile = img_cfg.get("Img_Cfg", "efuse_mask_file")
             cfg = BFConfigParser()
             cfg.read(self.eflash_loader_cfg)
             cfg.set('EFUSE_CFG', 'file', convert_path(os.path.relpath(efusefile, app_path)))
@@ -693,7 +705,8 @@ class BflbIotTool(object):
                 d_files.append("chips/" + chipname + "/img_create_iot/img.bin")
                 d_addrs.append(hex(pt_parcel['fw_addr'] + 0x1000)[2:])
     
-        if ro_params is not None and len(ro_params) > 0 and pt_parcel['conf_addr'] is not None:
+        conf_addr = pt_parcel.get('conf_addr', None)
+        if ro_params is not None and len(ro_params) > 0 and conf_addr is not None:
             bl_ro_device_tree.bl_ro_params_device_tree(ro_params,
                                                        chipnamedir + "/device_tree/ro_params.dtb")
             d_files.append("chips/" + chipname + "/device_tree/ro_params.dtb")
@@ -765,6 +778,22 @@ class BflbIotTool(object):
         #gol.GlobalVar.values = config
         self.config = config
 
+        if chiptype == "bl702":
+            cfg_t = BFConfigParser()
+            cfg_t.read(self.bh_cfg_file)
+            if "BOOTHEADER_CPU0_CFG" in cfg_t.sections():
+                bootheader_section_name = "BOOTHEADER_CPU0_CFG"
+            else:
+                bootheader_section_name = "BOOTHEADER_CFG"
+            if config["check_box"]['boot2_download'] is True:
+                boot2_en = False
+                cfg_t.set(bootheader_section_name, 'mfg_id', '0xff')
+                cfg_t.write(self.bh_cfg_file)
+            else:
+                boot2_en = True
+                cfg_t.set(bootheader_section_name, 'mfg_id', '0xc2')
+                cfg_t.write(self.bh_cfg_file)
+
         cfg = BFConfigParser()
         cfg.read(self.eflash_loader_cfg)
         if cfg.has_option("FLASH_CFG", "flash_id"):
@@ -818,6 +847,12 @@ class BflbIotTool(object):
                 bflb_utils.printf("create partition.bin, pt_new is True")
                 pt_helper.create_pt_table(partition_path)
             pt_parcel = pt_helper.construct_table()
+            if chiptype == "bl702":
+                cfg_t = BFConfigParser()
+                cfg_t.read(self.bh_cfg_file)
+                cfg_t.set("BOOTHEADER_CFG", 'boot2_pt_table_0', "0x%X" % pt_parcel['pt_addr0'])
+                cfg_t.set("BOOTHEADER_CFG", 'boot2_pt_table_1', "0x%X" % pt_parcel['pt_addr1'])
+                cfg_t.write(self.bh_cfg_file)
         else:
             bflb_utils.set_error_code("0076")
             return bflb_utils.errorcode_msg()
@@ -852,13 +887,20 @@ class BflbIotTool(object):
                 bflb_utils.printf(error)
                 bflb_utils.set_error_code("0067")
                 return bflb_utils.errorcode_msg()
-    
-        if chiptype == "bl702":
-            if config["check_box"]['boot2_download'] is True:
-                boot2_en = False
-            else:
-                boot2_en = True
-    
+
+        # set boot2 header crc and hash ignore
+        cfg_t = BFConfigParser()
+        cfg_t.read(self.bh_cfg_file)
+        if "BOOTHEADER_CPU0_CFG" in cfg_t.sections():
+                bootheader_section_name = "BOOTHEADER_CPU0_CFG"
+        else:
+            bootheader_section_name = "BOOTHEADER_CFG"
+        crc_ignore = cfg_t.get(bootheader_section_name, 'crc_ignore')
+        hash_ignore = cfg_t.get(bootheader_section_name, 'hash_ignore')
+        cfg_t.set(bootheader_section_name, 'crc_ignore', 1)
+        cfg_t.set(bootheader_section_name, 'hash_ignore', 1)
+        cfg_t.write(self.bh_cfg_file)
+
         if config["check_box"]['boot2_download'] is True:
             boot2 = config['input_path']['boot2_bin_input']
             if boot2 is not None and len(boot2) > 0:
@@ -878,7 +920,14 @@ class BflbIotTool(object):
             self.bl60x_fw_boot_head_gen(True, config['param'][chip_xtal], self.bh_cfg_file,
                                    config["check_box"]['encrypt'], config["check_box"]['sign'],
                                    chipname, chiptype, cpu_type, boot2_en)
-                   
+
+        # recover bootheader cfg file crc and hash ignore
+        cfg_t = BFConfigParser()
+        cfg_t.read(self.bh_cfg_file)
+        cfg_t.set(bootheader_section_name, 'crc_ignore', crc_ignore)
+        cfg_t.set(bootheader_section_name, 'hash_ignore', hash_ignore)
+        cfg_t.write(self.bh_cfg_file)
+
         if config["check_box"]['bin_download'] is True:
             bin = config['input_path']['cfg2_bin_input']
             if bin is not None and len(bin) > 0:
@@ -898,11 +947,11 @@ class BflbIotTool(object):
                 self.bl60x_image_gen(chipname, chiptype, cpu_type, "fw", bin, 
                                 config["param"]['aes_key'], config["param"]['aes_iv'],
                                 config["input_path"]["publickey"], config["input_path"]["privatekey"])
-                self.bl60x_mfg_ota_bin_gen(chipname, chiptype, cpu_type)
+                self.bl60x_mfg_ota_bin_gen(chipname, chiptype, cpu_type, config["param"]["version"], config["param"]["ota"])
                 bin_d = True
     
         if config["check_box"]['media_download'] is True:
-            media_bin = config['input_path']['meida_bin_input']
+            media_bin = config['input_path']['media_bin_input']
             if media_bin is not None and len(media_bin) > 0:
                 try:
                     shutil.copyfile(media_bin, os.path.join(chip_path, chipname, "img_create_iot", "media.bin"))
@@ -950,19 +999,18 @@ class BflbIotTool(object):
                 mfg_d = True
         return self.bl60x_mfg_flasher_eflash_loader_cfg(chipname, chiptype, bin_d, boot2_d, ro_params_d,
                                                    pt_parcel, media_bin_d, mfg_d)
-    
-    
+
 
     def flasher_download_thread(self, chipname, chiptype, act, config, callback=None):
         self.config = config
         error = None
         cpu_type = None   
         ota_path = os.path.join(chip_path, chipname, "ota")
-        imgcreate2_path = os.path.join(chip_path, chipname, "img_create_mcu")
+        imgcreate_path = os.path.join(chip_path, chipname, "img_create_iot")
         if not os.path.exists(ota_path):
             os.makedirs(ota_path)
-        if not os.path.exists(imgcreate2_path):
-            os.makedirs(imgcreate2_path)
+        if not os.path.exists(imgcreate_path):
+            os.makedirs(imgcreate_path)
     
         if chipname in gol.cpu_type.keys():
             cpu_type = gol.cpu_type[chipname][0]
@@ -998,13 +1046,16 @@ class BflbIotTool(object):
             bflb_utils.printf("eflash loader bin is " + get_eflash_loader(bl60x_xtal))
             eflash_loader_bin = os.path.join(chip_path, chipname,
                                              "eflash_loader/" + get_eflash_loader(bl60x_xtal))
-    
+
             if config["check_box"]["download_single"] is True and act == "download":
                 cfg = BFConfigParser()
                 cfg.read(self.eflash_loader_cfg)
-                files_str = config["input_path"]["img_bin_input"]
+                files_str = config["input_path"]["img_bin_input"]        
+                files_single = os.path.join(imgcreate_path, "img_single.bin") 
+                shutil.copyfile(files_str, files_single)
+                files_single = "chips/" + chipname + '/img_create_iot/img_single.bin'
                 addrs_str = config["param"]["addr"].replace("0x", "")
-                cfg.set('FLASH_CFG', 'file', files_str)
+                cfg.set('FLASH_CFG', 'file', files_single)
                 cfg.set('FLASH_CFG', 'address', addrs_str)
                 cfg.write(self.eflash_loader_cfg, 'w')
                 self.eflash_loader_t = eflash_loader.BflbEflashLoader(chipname, chiptype)
@@ -1017,16 +1068,19 @@ class BflbIotTool(object):
                     args = parser_eflash.parse_args(options)
                     error = self.eflash_loader_t.efuse_flash_loader(args, self.eflash_loader_cfg,
                                                                eflash_loader_bin, callback, None, None)
+                    self.eflash_loader_t.object_status_clear()
                 else:
                     options = ["--write", "--flash"]
                     args = parser_eflash.parse_args(options)
                     error = self.eflash_loader_t.efuse_flash_loader(args, self.eflash_loader_cfg,
                                                                eflash_loader_bin, callback, None, None)
+                    self.eflash_loader_t.object_status_clear()
             # generation partition table/boot2/fw bin files and rf files
             elif self.flasher_download_cfg_ini_gen(chipname, chiptype, cpu_type, config) is True:
                 if act == "download":
                     # burn into flash
                     self.eflash_loader_t = eflash_loader.BflbEflashLoader(chipname, chiptype)
+                    self.eflash_loader_t.set_config_file(self.bh_cfg_file, "")
                     if config["check_box"]['ckb_erase_all'] == "True":
                         self.bl60x_mfg_flasher_erase_all(True)
                     else:
@@ -1046,6 +1100,7 @@ class BflbIotTool(object):
                     error = self.eflash_loader_t.efuse_flash_loader(args, self.eflash_loader_cfg,
                                                                eflash_loader_bin, callback,
                                                                self.create_simple_callback, None)
+                    self.eflash_loader_t.object_status_clear()
             else:
                 error = self.flasher_download_cfg_ini_gen(chipname, chiptype, cpu_type, config)
                 bflb_utils.printf("Please check your partition table file")
@@ -1054,8 +1109,8 @@ class BflbIotTool(object):
             error = str(e)
         finally:
             return error
-        
-        
+
+
     def create_simple_callback(self):
         cpu_type = None
         if self.chipname in gol.cpu_type.keys():
@@ -1076,7 +1131,7 @@ class BflbIotTool(object):
             traceback.print_exc(limit=10, file=sys.stdout)
             ret = str(e)
             return False, ret
-    
+
 
 def flasher_download_cmd(args):
     config = toml.load(args.config)
@@ -1091,9 +1146,9 @@ def flasher_download_cmd(args):
     
 
 def iot_download_cmd(args):
-    chipname = args.chipname
+    chipname = args.chipname.lower()
     chiptype = chip_dict.get(chipname, "unkown chip type") 
-    partition_cfg = os.path.join(chip_path, chipname, "partition/partition_cfg_2M.toml") 
+    #partition_cfg = os.path.join(chip_path, chipname, "partition/partition_cfg_2M.toml") 
     config = dict()
     config["param"] = dict()
     config["check_box"] = dict()
@@ -1115,9 +1170,9 @@ def iot_download_cmd(args):
     config["check_box"]["encrypt"] = False
     config["check_box"]["sign"] = False
     config["input_path"]["dts_input"] = args.dts
-    config["input_path"]["pt_bin_input"] = partition_cfg
+    #config["input_path"]["pt_bin_input"] = partition_cfg
     config["input_path"]["cfg2_bin_input"] = args.firmware
-    config["input_path"]["meida_bin_input"] = ""
+    config["input_path"]["media_bin_input"] = ""
     config["input_path"]["romfs_dir_input"] = ""
     config["input_path"]["mfg_bin_input"] = ""
     config["input_path"]["publickey"] = ""
@@ -1125,6 +1180,15 @@ def iot_download_cmd(args):
     config["check_box"]["download_single"] = args.single
     config["input_path"]["img_bin_input"] = args.firmware
     config["param"]["addr"] = "0x" + args.addr
+    config["param"]["version"] = ""
+    config["param"]["ota"] = ""
+
+    if not os.path.exists(args.pt):
+        config["input_path"]["pt_bin_input"] = os.path.join(chip_path, chipname, "partition/partition_cfg_2M.toml") 
+    else:
+        config["input_path"]["pt_bin_input"] = args.pt
+    bflb_utils.printf("Partition table is " + config["input_path"]["pt_bin_input"])      
+
     
     if chiptype == "bl702":
         config["check_box"]["boot2_download"] = False
@@ -1133,35 +1197,36 @@ def iot_download_cmd(args):
             config["param"][chip_xtal] = "32M"
         else:   
             config["param"][chip_xtal] = args.xtal 
-        if not args.dts: 
+        if not os.path.exists(args.dts): 
             config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"IoTKitA_32M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl602":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", boot2bin)
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", boot2_dir, "boot2_iap_release.bin")
         if not args.xtal: 
             config["param"][chip_xtal] = "40M"
         else:   
             config["param"][chip_xtal] = args.xtal 
-        if not args.dts: 
+        if not os.path.exists(args.dts): 
             config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"IoTKitA_40M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl60x":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", boot2bin)
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", "blsp_boot2.bin")
         if not args.xtal: 
             config["param"][chip_xtal] = "38.4M"
         else:   
             config["param"][chip_xtal] = args.xtal 
-        if not args.dts: 
+        if not os.pasth.exists(args.dts): 
             config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"avb_38.4M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     else:
         bflb_utils.printf("Chip type is not correct")
         return
+    bflb_utils.printf("Device tree is " + config["input_path"]["dts_input"])      
     
     if config["param"]["interface_type"].lower() == "jlink" and args.baudrate > 12000:
         config["param"]["speed_jlink"] = "12000"
@@ -1176,7 +1241,10 @@ def iot_download_cmd(args):
     if act == "build":
         f_org = os.path.join(chip_path, args.chipname, "img_create_iot", "whole_flash_data.bin")
         f = "firmware.bin"
-        shutil.copyfile(f_org, f)
+        try:
+            shutil.copyfile(f_org, f)
+        except Exception as error:
+            pass
     
     
 def run():    
@@ -1197,12 +1265,15 @@ def run():
     parser.add_argument("--baudrate", dest="baudrate", default=115200, type=int, help="the speed at which to communicate")
     parser.add_argument("--xtal", dest="xtal", help="xtal type")
     parser.add_argument("--dts", dest="dts", help="device tree") 
+    parser.add_argument("--pt", dest="pt", help="partition table") 
     parser.add_argument("--firmware", dest="firmware", default=firmware_default, help="image to write")  
     parser.add_argument("--build", dest="build", action="store_true", help="build image") 
     parser.add_argument("--erase", dest="erase", action="store_true", help="chip erase")
     parser.add_argument("--single", dest="single", action="store_true", help="single download")
     parser.add_argument("--addr", dest="addr", default="0", help="address to write")
     parser.add_argument('--config', dest="config", help='config file')
+    #parser.add_argument('--ota', dest="ota", help='ota dir')
+    #parser.add_argument('--version', dest="version", help='version')
     args = parser.parse_args()
     bflb_utils.printf("==================================================")
     bflb_utils.printf("Chip name is %s" % args.chipname)  
