@@ -35,17 +35,23 @@ except ImportError:
 from libs import bflb_utils
 from libs import bflb_img_create
 from libs import bflb_interface_uart
+from libs import bflb_interface_sdio
 
 
 class BflbImgLoader(object):
 
-    def __init__(self, chiptype="bl60x", createcfg=None):
-        self.bflb_boot_if = bflb_interface_uart.BflbUartPort()
+    def __init__(self, chiptype="bl60x", interface="uart", createcfg=None):
+        self.bflb_boot_if = None
         self._imge_fp = None
         self._segcnt = 0
         self._chip_type = chiptype
         self._create_cfg = createcfg
 
+        if interface == "uart":
+            self.bflb_boot_if = bflb_interface_uart.BflbUartPort()
+        elif interface == "sdio":
+            self.bflb_boot_if = bflb_interface_sdio.BflbSdioPort()
+
         self._bootrom_cmds = {
             "get_boot_info": {
                 "cmd_id": "10",
@@ -57,7 +63,7 @@ class BflbImgLoader(object):
                 "data_len": "00b0",
                 "callback": None
             },
-            "606p_load_boot_header": {
+            "808_load_boot_header": {
                 "cmd_id": "11",
                 "data_len": "0180",
                 "callback": None
@@ -167,7 +173,7 @@ class BflbImgLoader(object):
                 tmp = bflb_utils.bytearray_reverse(read_data[120:124])
                 self._segcnt = bflb_utils.bytearray_to_int(tmp)
                 bflb_utils.printf("segcnt is ", self._segcnt)
-            elif section == "606p_load_boot_header":
+            elif section == "808_load_boot_header":
                 tmp = bflb_utils.bytearray_reverse(read_data[136:140])
                 self._segcnt = bflb_utils.bytearray_to_int(tmp)
                 bflb_utils.printf("segcnt is ", self._segcnt)
@@ -193,6 +199,10 @@ class BflbImgLoader(object):
         # in case data len change for some case
         tmp = bflb_utils.int_to_2bytearray_l(len(read_data))
         data = cmd_id + bytearray(1) + tmp + read_data
+
+        if self._chip_type == "bl702" and section == "run_image":
+            sub_module = __import__("libs." + self._chip_type, fromlist=[self._chip_type])
+            data = sub_module.chiptype_patch.img_load_create_predata_before_run_img()
         self.bflb_boot_if.if_write(data)
         if section == "get_boot_info" or section == "load_seg_header":
             res, data_read = self.bflb_boot_if.if_deal_response()
@@ -245,7 +255,7 @@ class BflbImgLoader(object):
     def boot_install_cmds_callback(self):
         self._bootrom_cmds.get("get_boot_info")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_boot_header")["callback"] = self.boot_process_load_cmd
-        self._bootrom_cmds.get("606p_load_boot_header")["callback"] = self.boot_process_load_cmd
+        self._bootrom_cmds.get("808_load_boot_header")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_publick_key")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_publick_key2")["callback"] = self.boot_process_load_cmd
         self._bootrom_cmds.get("load_signature")["callback"] = self.boot_process_load_cmd
@@ -314,7 +324,8 @@ class BflbImgLoader(object):
                             reset_revert=True,
                             cutoff_time=0,
                             shake_hand_retry=2,
-                            boot2_load=0):
+                            iap_timeout=0,
+                            boot_load=True):
         self.bflb_boot_if.if_init(comnum, sh_baudrate, self._chip_type)
 
         self.boot_install_cmds_callback()
@@ -322,7 +333,7 @@ class BflbImgLoader(object):
             self.bflb_boot_if.if_set_602a0_download_fix(False)
         ret = self.bflb_boot_if.if_shakehand(do_reset, reset_hold_time, shake_hand_delay,
                                              reset_revert, cutoff_time, shake_hand_retry,
-                                             boot2_load)
+                                             iap_timeout, boot_load)
         if self._chip_type == "bl602":
             self.bflb_boot_if.if_set_602a0_download_fix(False)
         if ret != "OK":
@@ -353,9 +364,14 @@ class BflbImgLoader(object):
         data_read = binascii.hexlify(data_read)
         bflb_utils.printf("data read is ", data_read)
         bootinfo = data_read.decode("utf-8")
-        bflb_utils.printf(
-            "========= ChipID: ", bootinfo[34:36] + bootinfo[32:34] + bootinfo[30:32] +
-            bootinfo[28:30] + bootinfo[26:28] + bootinfo[24:26], " =========")
+        if self._chip_type == "bl702":
+            bflb_utils.printf(
+                "========= ChipID: ", bootinfo[32:34] + bootinfo[34:36] + bootinfo[36:38] + 
+                bootinfo[38:40] + bootinfo[40:42] + bootinfo[42:44] + bootinfo[44:46] + bootinfo[46:48], " =========")
+        else:
+            bflb_utils.printf(
+                "========= ChipID: ", bootinfo[34:36] + bootinfo[32:34] + bootinfo[30:32] +
+                bootinfo[28:30] + bootinfo[26:28] + bootinfo[24:26], " =========")
         # bflb_utils.printf(int(data_read[10:12], 16))
         sign = 0
         encrypt = 0
@@ -365,7 +381,7 @@ class BflbImgLoader(object):
         elif self._chip_type == "bl602" or self._chip_type == "bl702":
             sign = int(data_read[8:10], 16)
             encrypt = int(data_read[10:12], 16)
-        elif self._chip_type == "bl606p":
+        elif self._chip_type == "bl808":
             if group == 0:
                 sign = int(data_read[8:10], 16)
                 encrypt = int(data_read[12:14], 16)
@@ -391,8 +407,8 @@ class BflbImgLoader(object):
             self._imge_fp = open(file, 'rb')
 
         # start to process load flow
-        if self._chip_type == "bl606p":
-            ret, dmy = self.boot_process_one_section("606p_load_boot_header", 0)
+        if self._chip_type == "bl808":
+            ret, dmy = self.boot_process_one_section("808_load_boot_header", 0)
         else:
             ret, dmy = self.boot_process_one_section("load_boot_header", 0)
         if ret.startswith("OK") is False:
@@ -401,14 +417,14 @@ class BflbImgLoader(object):
             ret, dmy = self.boot_process_one_section("load_publick_key", 0)
             if ret.startswith("OK") is False:
                 return ret
-            if self._chip_type == "bl60x" or self._chip_type == "bl606p":
+            if self._chip_type == "bl60x" or self._chip_type == "bl808":
                 ret, dmy = self.boot_process_one_section("load_publick_key2", 0)
                 if ret.startswith("OK") is False:
                     return ret
             ret, dmy = self.boot_process_one_section("load_signature", 0)
             if ret.startswith("OK") is False:
                 return ret
-            if self._chip_type == "bl60x" or self._chip_type == "bl606p":
+            if self._chip_type == "bl60x" or self._chip_type == "bl808":
                 ret, dmy = self.boot_process_one_section("load_signature2", 0)
                 if ret.startswith("OK") is False:
                     return ret
@@ -499,15 +515,12 @@ class BflbImgLoader(object):
                          reset_revert=True,
                          cutoff_time=0,
                          shake_hand_retry=2,
-                         boot2_load=0):
+                         iap_timeout=0,
+                         boot_load=True):
         bflb_utils.printf("========= image get bootinfo =========")
         ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time,
                                        shake_hand_delay, reset_revert, cutoff_time,
-                                       shake_hand_retry, boot2_load)
-        # if ret == "shake hand fail" or ret=="change rate fail":
-        #    bflb_utils.printf("img load shake hande again")
-        # ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time, shake_hand_delay, reset_revert, cutoff_time)
-
+                                       shake_hand_retry, iap_timeout, boot_load)
         if ret == "shake hand fail" or ret == "change rate fail":
             bflb_utils.printf("shake hand fail")
             self.bflb_boot_if.if_close()
@@ -535,15 +548,13 @@ class BflbImgLoader(object):
                          reset_revert=True,
                          cutoff_time=0,
                          shake_hand_retry=2,
-                         boot2_load=0):
+                         iap_timeout=0,
+                         boot_load=True):
         bflb_utils.printf("========= image load =========")
         success = True
         ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time,
                                        shake_hand_delay, reset_revert, cutoff_time,
-                                       shake_hand_retry, boot2_load)
-        # if ret == "shake hand fail" or ret=="change rate fail":
-        #    bflb_utils.printf("img load shake hande again")
-        # ret = self.img_load_shake_hand(comnum, sh_baudrate, wk_baudrate, do_reset, reset_hold_time, shake_hand_delay, reset_revert, cutoff_time)
+                                       shake_hand_retry, iap_timeout, boot_load)
         if ret == "shake hand fail" or ret == "change rate fail":
             bflb_utils.printf("shake hand fail")
             self.bflb_boot_if.if_close()
