@@ -9,6 +9,7 @@ import ecdsa
 from libs import bflb_utils
 from libs.bflb_utils import img_create_sha256_data, img_create_encrypt_data
 from libs.bflb_configobj import BFConfigParser
+from libs.bl702.bootheader_cfg_keys import bootheader_len as header_len
 
 keyslot0 = 28
 keyslot1 = keyslot0 + 16
@@ -163,8 +164,8 @@ def img_create_update_bootheader_if(bootheader_data, hash, seg_cnt):
         # do nothing
         bflb_utils.printf("Header crc ignored")
     else:
-        hd_crcarray = bflb_utils.get_crc32_bytearray(bootheader_data[0:176 - 4])
-        bootheader_data[176 - 4:176] = hd_crcarray
+        hd_crcarray = bflb_utils.get_crc32_bytearray(bootheader_data[0:header_len - 4])
+        bootheader_data[header_len - 4:header_len] = hd_crcarray
         bflb_utils.printf("Header crc: ", binascii.hexlify(hd_crcarray))
     return bootheader_data
 
@@ -185,10 +186,10 @@ def img_create_update_bootheader(bootheader_data, hash, seg_cnt):
         # do nothing
         bflb_utils.printf("Header crc ignored")
     else:
-        hd_crcarray = bflb_utils.get_crc32_bytearray(bootheader_data[0:176 - 4])
-        bootheader_data[176 - 4:176] = hd_crcarray
+        hd_crcarray = bflb_utils.get_crc32_bytearray(bootheader_data[0:header_len - 4])
+        bootheader_data[header_len - 4:header_len] = hd_crcarray
         bflb_utils.printf("Header crc: ", binascii.hexlify(hd_crcarray))
-    return bootheader_data[0:176]
+    return bootheader_data[0:header_len]
 
 
 # update segment header according segdata
@@ -251,8 +252,8 @@ def encrypt_loader_bin_do(file, sign, encrypt, createcfg):
 
         with open(file, "rb") as fp:
             load_helper_bin = fp.read()
-            load_helper_bin_header = load_helper_bin[0:176]
-            load_helper_bin_body = load_helper_bin[176:]
+            load_helper_bin_header = load_helper_bin[0:header_len]
+            load_helper_bin_body = load_helper_bin[header_len:]
 
         if load_helper_bin_header != bytearray(0) and load_helper_bin_body != bytearray(0):
             # encrypt body
